@@ -8,7 +8,7 @@ class LisaPluginTestCase(unittest.TestCase):
         self.pluginManager = PluginManagerSingleton.get()
 
     def test_a_install_plugin_ok(self):
-        answer = self.pluginManager.installPlugin(plugin_name="UnitTest", test_mode=True)
+        answer = self.pluginManager.installPlugin(plugin_name="UnitTest", test_mode=True, version='0.1.6')
         self.assertEqual(answer['status'], "success")
 
     def test_aa_install_plugin_fail(self):
@@ -31,26 +31,34 @@ class LisaPluginTestCase(unittest.TestCase):
         answer = self.pluginManager.enablePlugin(plugin_name="UnitTest")
         self.assertEqual(answer['status'], "fail")
 
-    def test_d_load_plugin(self):
+    def test_d_upgrade_plugin_ok(self):
+        answer = self.pluginManager.upgradePlugin(plugin_name="UnitTest", test_mode=True)
+        self.assertEqual(answer['status'], "success")
+
+    def test_dd_upgrade_plugin_fail(self):
+        answer = self.pluginManager.upgradePlugin(plugin_name="UnitTest", test_mode=True)
+        self.assertEqual(answer['status'], "fail")
+
+    def test_e_load_plugin(self):
         answer = self.pluginManager.loadPlugins()
         test_list = ['UnitTest']
         self.assertListEqual(answer, test_list)
 
-    def test_e_methodList_plugin(self):
+    def test_f_methodList_plugin(self):
         answer = self.pluginManager.methodListPlugin()
         methodlist = [{'methods': ['test'], 'plugin': u'UnitTest'}, {'core': 'intents', 'methods': ['list']}]
         self.assertListEqual(answer, methodlist)
 
-    def test_f_create_plugin(self):
+    def test_g_create_plugin(self):
         os.environ.setdefault("DJANGO_SETTINGS_MODULE", "lisa.server.web.weblisa.settings")
         answer = self.pluginManager.createPlugin(plugin_name="TestPlugin", author_name="TestAuthor",
                                                  author_email="test@test.com")
         self.assertEqual(answer['status'], "success")
 
-    def test_g_uninstall_plugin(self):
+    def test_h_uninstall_plugin(self):
         answer = self.pluginManager.uninstallPlugin(plugin_name="UnitTest")
         self.assertEqual(answer['status'], "success")
 
-    def test_gg_uninstall_plugin(self):
+    def test_hh_uninstall_plugin(self):
         answer = self.pluginManager.uninstallPlugin(plugin_name="UnitTest")
         self.assertEqual(answer['status'], "fail")
\ No newline at end of file
